#
# spec file for package obconf-qt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           obconf-qt
Version:        0.16.4
Release:        bp156.1.2
Summary:        OpenBox window manager configuration tool
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/GUI/LXQt
URL:            http://www.lxqt.org
Source:         https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.5.0
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  lxqt-build-tools-devel >= 0.8.0
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.12.0
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(lxqt)
BuildRequires:  pkgconfig(obrender-3.5)
BuildRequires:  pkgconfig(obt-3.5)
Requires(post): desktop-file-utils
Requires(post): update-alternatives
Requires(postun):update-alternatives
Requires(pre):  desktop-file-utils
Recommends:     %{name}-lang
Conflicts:      obconf

%description
Configuration tool for the OpenBox Window Manager.
This tool is used by LXQt to configure OpenBox, since it is
used as the default WindowManager in LXQt.

%lang_package

%prep
%setup -q

%build
%cmake \
      -DPULL_TRANSLATIONS=OFF
%make_jobs

%install
%cmake_install
install -dm 755 %{buildroot}%{_sysconfdir}/alternatives/
touch %{buildroot}%{_sysconfdir}/alternatives/obconf
ln -s %{_sysconfdir}/alternatives/obconf \
    %{buildroot}%{_bindir}/obconf

%find_lang %{name} --with-qt

%post
%{_sbindir}/update-alternatives --install \
    %{_bindir}/obconf \
    obconf \
    %{_bindir}/%{name} \
    40

%postun
if [ $1 -eq 0 ]; then
    %{_sbindir}/update-alternatives --remove obconf \
        %{_bindir}/%{name}
fi

%files
%license COPYING
%doc AUTHORS README.md
%{_bindir}/obconf
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.??g
%ghost %{_sysconfdir}/alternatives/obconf

%files lang -f %{name}.lang
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations
%{_datadir}/%{name}/translations/*

%changelog
* Sun Jan 14 2024 Shawn Dunn <sfalken@opensuse.org>
- Update to 0.16.4:
  * Fixed Compilation.
* Thu Aug 17 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.16.3:
  * Added missing copyright info.
  * Bumped the minimum required version of cmake to 3.5.0 (to silence a compilation warning).
  * Translation updates.
* Fri Mar 11 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.16.2:
  * Fixed the option for centering window on opening.
  * Prevented elided text in left pane.
  * Updated translations.
* Tue May 18 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.16.1
  * Translation updates
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * Bumped version to 0.16.0.
  * Translation updates.
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed obconf-qt.keyring to tsujan's key
* Fri Apr 24 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 0.15.0
  * Code cleanup and small fixes.
* Fri Mar  1 2019 mvetter@suse.com
- Update to 0.14.1:
  * Only translations was changed
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Fixed dysfunctional *.obt Archive generation
- Move translation from lxqt-l10n into package
* Tue May 22 2018 mvetter@suse.com
- Update to 0.13.0:
  * Bumped minor version to 13
  * Spanish translation update
  * CMake: Prevent in-source builds
  * fixed lxde mentions
  * Add Traditional Chinese translation
  * Add Traditional Chinese translation
  * Add Simplified Chinese translation
  * Fixes Qt4 build
  * cmake: Use LXQtCompilerSettings
  * cmake: Handle CMP0071
  * cmake: Make it compile with Qt4
  * cmake: Update CMake minimum required version
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.12.0:
  * Bump version to 0.12.0
  * Don't export github templates
  * Added Lithuanian language
  * liblxqt dont make sense here
  * Copied issue template
  * Drops Qt5Core_VERSION_STRING
  * set Qt::AA_UseHighDpiPixmaps to true
  * Added default CMAKE_BUILD_TYPE and versioning (#29)
  * added Polish translation
  * Add obconf-qt_ca.desktop (Catalan)
  * Update AUTHORS
  * Added *da.desktop
* Fri Feb 24 2017 sfalken@opensuse.org
- Update to 0.11.1:
  * Create obconf-qt_fr.desktop
  * Use the LXQtCompilerSettings
  * Use lxqt-build-tools translation modules
  * Use the new lxqt-build-tools package
  * Remove cpack (#22)
  * README.md: Update dependencies
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.11.0:
  * Bump version to 0.2.0 (#20)
  * Extend README.md
  * occured -> occurred
  * build: Use external translations
  * ts-files removal
  * Bump year
  * Work around grep 2.23 new behaviour
  * Don't track $IDE settings
  * Japanese translation update
  * Reflect replacement README --> README.md in CMakeLists.txt
  * Use markdown for README
  * Update translations
  * Fix license file
  * Hungarian translations added
  * src/CMakeLists.txt: do not completely overwrite CMAKE_CXX_FLAGS
  * Use GNUInstallDirs
  * Small build fix (themes dir path)
  * Update German translation
  * Update translations.
  * Update the About dialog.
  * Port missing "Dock" options from obconf gtk+ version.
  * Support changing the name of desktops.
  * German translation
  * Default to Qt5
- Remove obconf-qt-0.1.0_qt5-support.patch
* Sun Jan 25 2015 sfalken@opensuse.org
- Added conditionals and BuildRequires for building on Fedora
* Wed May 14 2014 andrea@opensuse.org
- spec file cleanup for factory
* Tue May 13 2014 sfalken@opensuse.org
- Specfile cleanup
* Mon May 12 2014 sfalken@opensuse.org
- Removed fedora specfile, split into subproject
  Del:  obconf-qt-Fedora_20.spec
* Sat May 10 2014 sfalken@opensuse.org
- Ran spec-cleaner on openSUSE specfile
* Fri May  9 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add:  obconf-qt-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Added tarball for new stable release
  Add:  obconf-qt-0.1.0.tar.xz
  Del:  _service
* Fri Apr  4 2014 sfalken@opensuse.org
- Initial Source Upload
  Add: _service
  Add: obconf-qt.spec
  Add: obconf-qt.changes
